/**
 * Account settings route
 *
 * @author Pierre Hubert
 */

import React from "react";
import { useParams } from "react-router-dom";
import { AccountHelper, AdminAccount } from "../../helpers/AccountHelper";
import { AsyncWidget } from "../widgets/AsyncWidget";

export function AccountSettingsRoute() {
	let params: any = useParams();

	return <AccountSettingsRouteInner id={Number(params.id)} />;
}

interface SettingsRouteProps {
	id: number;
}

interface SettingsRouteState {
	account: AdminAccount;
}

class AccountSettingsRouteInner extends React.Component<
	SettingsRouteProps,
	SettingsRouteState
> {
	constructor(props: any) {
		super(props);

		this.load = this.load.bind(this);
		this.build = this.build.bind(this);
	}

	async load() {
		const account = await AccountHelper.getAdminInfo(this.props.id);

		this.setState({ account: account });
	}

	render() {
		return (
			<AsyncWidget
				key={this.props.id}
				errorMessage="Failed to load admin information!"
				onBuild={this.build}
				load={this.load}
			></AsyncWidget>
		);
	}

	build() {
		return <p>{this.state.account.email}</p>;
	}
}
